# Generated by Django 3.1a1 on 2020-06-08 12:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("message", "0001_implement_message_model"),
    ]

    operations = [
        migrations.AlterField(
            model_name="message",
            name="type",
            field=models.CharField(
                choices=[("CL", "Changelog"), ("SE", "Series"), ("NO", "Notice")],
                max_length=2,
            ),
        ),
    ]
