# Generated by Django 3.0.3 on 2020-04-09 16:23

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("slideshow", "0002_implement_slideshow_page_model"),
    ]

    operations = [
        migrations.CreateModel(
            name="SlideshowImage",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("position", models.PositiveSmallIntegerField(default=1)),
                ("title", models.CharField(max_length=100)),
                ("img", models.ImageField(upload_to="slideshow/")),
                ("img_alt", models.CharField(max_length=200)),
                ("caption", models.TextField(blank=True, default="")),
                (
                    "page",
                    models.ForeignKey(
                        db_index=False,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="images",
                        related_query_name="image",
                        to="slideshow.SlideshowPage",
                    ),
                ),
            ],
        ),
    ]
