# Generated by Django 3.0.3 on 2020-04-24 09:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("slideshow", "0003_implement_slideshow_image_model"),
    ]

    operations = [
        migrations.AlterField(
            model_name="slideshowimage",
            name="caption",
            field=models.TextField(
                blank=True, default="", verbose_name="caption (Markdown)"
            ),
        ),
        migrations.AlterField(
            model_name="slideshowpage",
            name="text",
            field=models.TextField(verbose_name="text (Markdown)"),
        ),
    ]
