# Generated by Django 3.0.3 on 2020-04-24 09:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("quiz", "0002_implement_quiz_answer_model"),
    ]

    operations = [
        migrations.AlterField(
            model_name="quizanswer",
            name="text",
            field=models.CharField(max_length=200, verbose_name="text (Markdown)"),
        ),
        migrations.AlterField(
            model_name="quizquestion",
            name="text",
            field=models.TextField(verbose_name="text (Markdown)"),
        ),
    ]
