# Generated by Django 3.0.7 on 2020-07-07 13:04

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("photograph", "0002_add_audio_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="photograph",
            name="content_type",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="contenttypes.ContentType",
            ),
        ),
        migrations.AddField(
            model_name="photograph",
            name="object_id",
            field=models.PositiveIntegerField(default=0),
        ),
    ]
