# Generated by Django 3.0.3 on 2020-03-20 15:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("quiz", "0001_implement_quiz_question_model"),
    ]

    operations = [
        migrations.CreateModel(
            name="QuizAnswer",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("text", models.CharField(max_length=200)),
                ("correct", models.BooleanField()),
                (
                    "feedback_correct",
                    models.CharField(blank=True, default="", max_length=400),
                ),
                (
                    "feedback_incorrect",
                    models.CharField(blank=True, default="", max_length=400),
                ),
                (
                    "question",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="answers",
                        related_query_name="answer",
                        to="quiz.QuizQuestion",
                    ),
                ),
            ],
        ),
    ]
