# Generated by Django 3.0.3 on 2020-04-24 09:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("glossary", "0002_update_image_upload_path"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glossaryentry",
            name="text",
            field=models.TextField(verbose_name="text (Markdown)"),
        ),
    ]
