# Generated by Django 3.0.6 on 2020-05-26 13:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("slideshow", "0004_add_verbose_name_to_text_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="slideshow",
            name="img",
            field=models.ImageField(blank=True, null=True, upload_to="slideshow/"),
        ),
        migrations.AddField(
            model_name="slideshow",
            name="img_alt",
            field=models.CharField(blank=True, default="", max_length=200),
        ),
    ]
